@@ -18,11 +18,13 @@ from signaux.signal_sysam import SignalSysam
 import base.temps_base
 import base.voie_base
 
+import signaux
 
 from sysam.sysam_4_methodes import Sysam4Methodes
 
 __all__ = ["demarrer_sysam"]
 
+ 
 def demarrer_sysam(liste_signaux=None):
     with SysamSP5(liste_signaux) as sysam:
         pass
@@ -39,7 +41,7 @@ def demarrer_sysam(liste_signaux=None):
 #                 os._exit(0)
 
 class SysamSP5(Sysam4Methodes):
-    def __init__(self, liste_signaux = None):
+    def __init__(self, liste_signaux):
         Sysam4Methodes.__init__(self, liste_signaux)
         print(self.chaine_mode)
         if "entree" in self.chaine_mode:
@@ -61,14 +63,18 @@ class SysamSP5(Sysam4Methodes):
         if "synchrone" in self.chaine_mode:
             self.sysam.acquerir_avec_sorties(*self.calculer_arguments_acquerir_avec_sorties())
             self.mettre_a_jour_entrees()
-        elif "entree" in self.chaine_mode:
+        elif "entree" in self.chaine_mode and "sortie" in self.chaine_mode:
             tmin, tmax = self.base_de_temps_entrees.calculer_liste_tmin_tmax()
             self.sysam.declencher_sorties(*self.calculer_arguments_declencher_sorties())
             if tmin != 0:
                 time.sleep(tmin)
             self.sysam.acquerir()
             self.mettre_a_jour_entrees()
-        elif "sortie" in self.chaine_mode:
+        elif "entree" in self.chaine_mode and "sortie" not in self.chaine_mode:
+            tmin, tmax = self.base_de_temps_entrees.calculer_liste_tmin_tmax()
+            self.sysam.acquerir()
+            self.mettre_a_jour_entrees()            
+        elif "sortie" in self.chaine_mode and "entree" not in self.chaine_mode:
             self.sysam.declencher_sorties(*self.calculer_arguments_declencher_sorties())
             test_fin = False
             while not test_fin:
@@ -95,34 +101,37 @@ class SysamSP5(Sysam4Methodes):
             s.base_de_temps.Nsysam = Nsysam
 
 if __name__ == "__main__":
-    liste_tmin_tmax_entrees_1 = [0, 2e-3]
-    Te_entrees_1 = 1e-4
+    liste_tmin_tmax = [0, 2e-3]
+    Te = 1e-4
 
-    liste_tmin_tmax_entrees_2 = [0, 2e-3]
-    Te_entrees_2 = 1e-4
+    N = 10
+    liste_signaux = []
+    for i in range(N):
+        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
-    liste_tmin_tmax_sortie_1 = [0, 2e-3]
-    Te_sortie_1 = 1e-4
+    # # tester acquisition non synchrone
+    # liste_signaux[0].configurer_voie("EA1")
+    # liste_signaux[1].configurer_voie("SA1")
+    # liste_signaux[2].configurer_voie("DIFF2")
 
-    liste_tmin_tmax_sortie_2 = [0, 2e-3]
-    Te_sortie_2 = 1e-4
+    # liste_signaux[2].configurer_trigger(0)
+    # sysam = SysamSP5(liste_signaux)
 
-    # s1 = SignalSysam("EA7", 10., liste_tmin_tmax_entrees_1, Te_entrees_1, "s1")
-    # s2 = SignalSysam("DIFF2", 10., liste_tmin_tmax_entrees_2, Te_entrees_2, "s2")
-    s3 = SignalGBF("carre", 1e3, 3, liste_tmin_tmax = liste_tmin_tmax_sortie_1, Te = Te_sortie_1, nom="s3")
-    s4 = SignalGBF("carre", 1e3, 4, liste_tmin_tmax = liste_tmin_tmax_sortie_1, Te = Te_sortie_2, nom="s4")
+    # SignalGBF.tracer_signaux(liste_signaux[0:3:2])
 
-    s3.configurer_voie("SA1", repetition = True)
-    s4.configurer_voie("SA1", repetition = True)
-    
-    # s1.configurer_trigger(0.)
+    # # tester acquisition synchrone
+    # liste_signaux[0].configurer_voie("EA1")
+    # liste_signaux[1].configurer_voie("SA1")
+    # liste_signaux[2].configurer_voie("DIFF2")
 
-    demarrer_sysam()
+    # sysam = SysamSP5(liste_signaux)
 
-    SignalSysam.tracer_signaux([s1, s2, s3, s4])
+    # SignalGBF.tracer_signaux(liste_signaux[0:3])
 
-    s8 = s1+s2
-    s9 = s3+s4
-    s10 = s1+s3
+    # tester acquisition sans entrées
+    liste_signaux[0].configurer_voie("EA1")
+    liste_signaux[1].configurer_voie("DIFF2")
 
-    print(s1.base_de_temps == s3.base_de_temps)
+    sysam = SysamSP5(liste_signaux)
+
+    SignalGBF.tracer_signaux(liste_signaux[0:2])
